Glossary
========

* Entity - entity is an object indexed by MatchBox
* Characteristic - is an attribute that can describe entity
* Trait - Characteristic's trait, a value by which given characteristic can describe entity